@@ -5,16 +5,15 @@ from __future__ import unicode_literals
 import json
 import re
 
-from django.utils.six.moves.urllib.parse import urlencode
-from django.utils.six import text_type
-
 from django.conf import settings
 from django.contrib.gis.measure import D
 from django.core.exceptions import ObjectDoesNotExist
 from django.http import HttpResponse, Http404, HttpResponseForbidden, HttpResponseBadRequest
 from django.template import loader, RequestContext
 from django.template.defaultfilters import escapejs
-from django.utils import importlib
+from django.utils.six import text_type
+from django.utils.six.moves.urllib.parse import urlencode
+from django.utils.translation import ugettext as _
 from django.views.generic import View
 
 from boundaries import kml
@@ -22,8 +21,10 @@ from boundaries.models import app_settings
 
 
 class RawJSONResponse(object):
+
     """APIView subclasses can return these if they have
     already-serialized JSON to return"""
+
     def __init__(self, content):
         self.content = content
 
@@ -31,7 +32,9 @@ class RawJSONResponse(object):
 class BadRequest(Exception):
     pass
 
+
 class APIView(View):
+
     """Base view class that serializes subclass responses to JSON.
 
     Subclasses should define get/post/etc. methods."""
@@ -75,7 +78,7 @@ class APIView(View):
         jsonresult = json.dumps(result, indent=4)
         t = loader.get_template('boundaries/apibrowser.html')
         json_url = request.path
-        params = dict([k, v.encode('utf-8')] for k,v in request.GET.items())
+        params = dict([k, v.encode('utf-8')] for k, v in request.GET.items())
         params.pop('format')
         if params:
             json_url += '?' + urlencode(params)
@@ -92,7 +95,9 @@ class APIView(View):
         c = RequestContext(request, ctx)
         return HttpResponse(t.render(c))
 
+
 class ModelListView(APIView):
+
     """Base API class for a list of resources.
 
     Subclasses should set the 'model' attribute to the appropriate model class.
@@ -135,7 +140,7 @@ class ModelListView(APIView):
         try:
             qs = self.filter(request, qs)
         except ValueError:
-            raise BadRequest("Invalid filter value")
+            raise BadRequest(_("Invalid filter value"))
         if hasattr(self.model, 'prepare_queryset_for_get_dicts'):
             qs = self.model.prepare_queryset_for_get_dicts(qs)
         paginator = Paginator(request.GET, qs, resource_uri=request.path)
@@ -146,7 +151,9 @@ class ModelListView(APIView):
             result['meta']['related'] = related
         return result
 
+
 class ModelGeoListView(ModelListView):
+
     """Adds geospatial support to ModelListView.
 
     Subclasses must set the 'allowed_geo_fields' attribute to a list
@@ -173,9 +180,9 @@ class ModelGeoListView(ModelListView):
                 try:
                     lat, lon = re.sub(r'[^\d.,-]', '', request.GET['contains']).split(',')
                     wkt_pt = 'POINT(%s %s)' % (lon, lat)
-                    qs = qs.filter(**{self.default_geo_filter_field + "__contains" : wkt_pt})
+                    qs = qs.filter(**{self.default_geo_filter_field + "__contains": wkt_pt})
                 except ValueError:
-                    raise BadRequest("Invalid latitude,longitude '%s' provided." % request.GET['contains'])
+                    raise BadRequest(_("Invalid latitude,longitude '%(value)s' provided.") % {'value': request.GET['contains']})
 
             if 'near' in request.GET:
                 lat, lon, range = request.GET['near'].split(',')
@@ -184,7 +191,7 @@ class ModelGeoListView(ModelListView):
                 unit = range[len(numeral):]
                 numeral = int(numeral)
                 kwargs = {unit: numeral}
-                qs = qs.filter(**{self.default_geo_filter_field + "__distance_lte" :(wkt_pt, D(**kwargs))})
+                qs = qs.filter(**{self.default_geo_filter_field + "__distance_lte": (wkt_pt, D(**kwargs))})
 
         return qs
 
@@ -200,34 +207,36 @@ class ModelGeoListView(ModelListView):
         try:
             qs = self.filter(request, qs)
         except ValueError:
-            raise BadRequest("Invalid filter value")
+            raise BadRequest(_("Invalid filter value"))
 
         if qs.count() > app_settings.MAX_GEO_LIST_RESULTS:
             return HttpResponseForbidden(
-                "Spatial-list queries cannot return more than %d resources; this query would return %s. Please filter your query."
-                % (app_settings.MAX_GEO_LIST_RESULTS, qs.count()))
+                _("Spatial-list queries cannot return more than %(expected)d resources; this query would return %(actual)s. Please filter your query.")
+                % {'expected': app_settings.MAX_GEO_LIST_RESULTS, 'actual': qs.count()})
 
         format = request.GET.get('format', 'json')
 
         if format in ('json', 'apibrowser'):
-            strings = ['{ "objects" : [ ']
-            strings.append(','.join( ('{"name": "%s","%s":%s}' % (escapejs(x[1]),field,x[0].geojson)
-                        for x in qs.values_list(field, self.name_field) )))
+            strings = ['{"objects": [']
+            strings.append(','.join(('{"name": "%s", "%s": %s}' % (escapejs(x[1]), field, x[0].geojson)
+                                     for x in qs.values_list(field, self.name_field))))
             strings.append(']}')
             return RawJSONResponse(''.join(strings))
         elif format == 'wkt':
-            return HttpResponse("\n".join((geom.wkt for geom in qs.values_list(field, flat=True))), mimetype="text/plain")
+            return HttpResponse("\n".join((geom.wkt for geom in qs.values_list(field, flat=True))), content_type="text/plain")
         elif format == 'kml':
             placemarks = [kml.generate_placemark(x[1], x[0]) for x in qs.values_list(field, self.name_field)]
             resp = HttpResponse(
                 kml.generate_kml_document(placemarks),
-                mimetype="application/vnd.google-earth.kml+xml")
+                content_type="application/vnd.google-earth.kml+xml")
             resp['Content-Disposition'] = 'attachment; filename="shape.kml"'
             return resp
         else:
             raise NotImplementedError
 
+
 class ModelDetailView(APIView):
+
     """Return the API representation of a single object.
 
     Subclasses must set the 'model' attribute to the appropriate model class.
@@ -248,7 +257,9 @@ class ModelDetailView(APIView):
         except ObjectDoesNotExist:
             raise Http404
 
+
 class ModelGeoDetailView(ModelDetailView):
+
     """Adds geospatial support to ModelDetailView
 
     Subclasses must set the 'allowed_geo_fields' attribute to a list
@@ -279,20 +290,23 @@ class ModelGeoDetailView(ModelDetailView):
         if format in ('json', 'apibrowser'):
             return RawJSONResponse(geom.geojson)
         elif format == 'wkt':
-            return HttpResponse(geom.wkt, mimetype="text/plain")
+            return HttpResponse(geom.wkt, content_type="text/plain")
         elif format == 'kml':
             resp = HttpResponse(
                 kml.generate_kml_document([kml.generate_placemark(name, geom)]),
-                mimetype="application/vnd.google-earth.kml+xml")
+                content_type="application/vnd.google-earth.kml+xml")
             resp['Content-Disposition'] = 'attachment; filename="shape.kml"'
             return resp
         else:
             raise NotImplementedError
 
+
 class Paginator(object):
+
     """
     Taken from django-tastypie. Thanks!
     """
+
     def __init__(self, request_data, objects, resource_uri=None, limit=None, offset=0, max_limit=1000, collection_name='objects'):
         """
         Instantiates the ``Paginator`` and allows for some configuration.
@@ -343,10 +357,10 @@ class Paginator(object):
         try:
             limit = int(limit)
         except ValueError:
-            raise BadRequest("Invalid limit '%s' provided. Please provide a positive integer." % limit)
+            raise BadRequest(_("Invalid limit '%(value)s' provided. Please provide a positive integer.") % {'value': limit})
 
         if limit < 0:
-            raise BadRequest("Invalid limit '%s' provided. Please provide a positive integer >= 0." % limit)
+            raise BadRequest(_("Invalid limit '%(value)s' provided. Please provide a positive integer >= 0.") % {'value': limit})
 
         if self.max_limit and (not limit or limit > self.max_limit):
             # If it's more than the max, we're only going to return the max.
@@ -372,10 +386,10 @@ class Paginator(object):
         try:
             offset = int(offset)
         except ValueError:
-            raise BadRequest("Invalid offset '%s' provided. Please provide an integer." % offset)
+            raise BadRequest(_("Invalid offset '%(value)s' provided. Please provide a positive integer.") % {'value': offset})
 
         if offset < 0:
-            raise BadRequest("Invalid offset '%s' provided. Please provide a positive integer >= 0." % offset)
+            raise BadRequest(_("Invalid offset '%(value)s' provided. Please provide a positive integer >= 0.") % {'value': offset})
 
         return offset
 
@@ -406,7 +420,7 @@ class Paginator(object):
         if offset - limit < 0:
             return None
 
-        return self._generate_uri(limit, offset-limit)
+        return self._generate_uri(limit, offset - limit)
 
     def get_next(self, limit, offset, count):
         """
@@ -416,7 +430,7 @@ class Paginator(object):
         if offset + limit >= count:
             return None
 
-        return self._generate_uri(limit, offset+limit)
+        return self._generate_uri(limit, offset + limit)
 
     def _generate_uri(self, limit, offset):
         if self.resource_uri is None:
