@@ -11,7 +11,7 @@ from django.template.defaultfilters import slugify
 from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import lazy
 from django.utils.safestring import mark_safe
-from django.utils.six import text_type, string_types
+from django.utils.six import binary_type, string_types, text_type
 from django.utils.translation import ugettext as _, ugettext_lazy
 
 from appconf import AppConf
@@ -305,14 +305,15 @@ class Geometry(object):
         """
         Converts a Polygon to a MultiPolygon.
         """
-        if geometry.__class__.__name__ == 'MultiPolygon':
+        value = geometry.__class__.__name__
+        if value == 'MultiPolygon':
             return geometry
-        elif geometry.__class__.__name__ == 'Polygon':
+        elif value == 'Polygon':
             multipolygon = OGRGeometry(OGRGeomType('MultiPolygon'))
             multipolygon.add(geometry)
             return multipolygon
         else:
-            raise ValueError(_('The geometry is neither a Polygon nor a MultiPolygon.'))
+            raise ValueError(_('The geometry is a %(value)s but must be a Polygon or a MultiPolygon.') % {'value': value})
 
 
 slug_re = re.compile(r'[–—]')  # n-dash, m-dash
@@ -322,12 +323,14 @@ slug_re = re.compile(r'[–—]')  # n-dash, m-dash
 class Feature(object):
 
     # @see https://github.com/django/django/blob/master/django/contrib/gis/gdal/feature.py
-    def __init__(self, feature, definition):
+    def __init__(self, feature, definition, srs=SpatialReference(4326), boundary_set=None):
         self.feature = feature
         self.definition = definition
+        self.geometry = Geometry(feature.geom).transform(srs)
+        self.boundary_set = boundary_set
 
     def __str__(self):
-        return str(self.feature)
+        return self.name
 
     def get(self, field):
         return self.feature.get(field)
@@ -357,20 +360,35 @@ class Feature(object):
 
     @property
     def metadata(self):
-        return dict((field, self.get(field)) for field in self.feature.fields)
+        d = {}
+        for field in self.feature.fields:
+            if isinstance(field, binary_type):
+                key = field.decode()
+            else:
+                key = field
+            d[key] = self.get(key)
+        return d
 
-    def create_boundary(self, boundary_set, geometry):
+    @property
+    def boundary_set(self):
+        return self._boundary_set
+
+    @boundary_set.setter
+    def boundary_set(self, value):
+        self._boundary_set = value
+
+    def create_boundary(self):
         return Boundary.objects.create(
-            set=boundary_set,
-            set_name=boundary_set.singular,
+            set=self.boundary_set,
+            set_name=self.boundary_set.singular,
             external_id=self.id,
             name=self.name,
             slug=self.slug,
             metadata=self.metadata,
-            shape=geometry.wkt,
-            simple_shape=geometry.simplify().wkt,
-            centroid=geometry.centroid,
-            extent=geometry.extent,
+            shape=self.geometry.wkt,
+            simple_shape=self.geometry.simplify().wkt,
+            centroid=self.geometry.centroid,
+            extent=self.geometry.extent,
             label_point=self.label_point,
         )
 
@@ -411,7 +429,7 @@ class Definition(object):
         self.dictionary.update(dictionary)
 
     def __str__(self):
-        return str(self.dictionary)
+        return self.dictionary['name']
 
     def __getitem__(self, key):
         return self.dictionary[key]
